@@ -1,5 +1,5 @@
 create_edit(
-    engine_id = "text-davinci-edit-001",
+    model = "text-davinci-edit-001",
     input = "What day of the wek is it?",
     instruction = "Fix the spelling mistakes"
 )
