@@ -1,5 +1,5 @@
 create_embedding(
-    engine_id = "text-similarity-babbage-001",
+    model = "text-similarity-babbage-001",
     input = c(
         "Ah, it is so boring to write documentation",
         "But examples are really crucial"
